[−][src]Enum solicit::http::session::StreamDataError
The enum represents errors that can be returned from the Stream::get_data_chunk method.
Variants
Indicates that the stream cannot provide any data, since it is closed for further writes from the peer's side.
A different error while trying to obtain the data chunk. Wraps a boxed Error impl.